@@ -20,16 +20,13 @@
 #ifndef KOLFLIB_EXPORT_H
 #define KOLFLIB_EXPORT_H
 
-/* needed for KDE_EXPORT and KDE_IMPORT macros */
-#include <kdemacros.h>
-
 #ifndef KOLFLIB_EXPORT
 # if defined(MAKE_KOLFPRIVATE_LIB)
    /* We are building this library */ 
-#  define KOLFLIB_EXPORT KDE_EXPORT
+#  define KOLFLIB_EXPORT Q_DECL_EXPORT
 # else
    /* We are using this library */ 
-#  define KOLFLIB_EXPORT KDE_IMPORT
+#  define KOLFLIB_EXPORT Q_DECL_IMPORT
 # endif
 #endif
 
